//! The Alchemy library is a data type to byte converter library.
//! Alchemy handles converting numbers to and from bytes
//! in either big or little endian format.
#![doc(html_logo_url="",
       html_favicon_url="http://cybermagesllc.com/favicon.ico",
       html_root_url="http://cybermagesllc.com")]
#![warn(missing_docs)]



#[macro_use]
mod macros;

mod byte_sized;
mod conversion_error;
mod converter;
mod endian;
mod transmutable;



pub use self::byte_sized::ByteSized;
pub use self::byte_sized::{U8_BYTES, U16_BYTES, U32_BYTES, U64_BYTES, USIZE_BYTES};
pub use self::byte_sized::{I8_BYTES, I16_BYTES, I32_BYTES, I64_BYTES, ISIZE_BYTES};
pub use self::byte_sized::{F32_BYTES, F64_BYTES};
pub use self::byte_sized::get_byte_size_of_string;
pub use self::conversion_error::ConversionError;
pub use self::converter::Converter;
pub use self::endian::{BigEndian, LittleEndian, PlatformEndian, NetworkEndian};
pub use self::endian::Endianess;
pub use self::endian::{network_to_platform_order, platform_to_network_order};
pub use self::endian::{get_network_endianess, get_platform_endianess};
pub use self::transmutable::Transmutable;
